// Sort numbes (positions) of output neurons into the given array by ascending activation.
// Uses bubble sort
void SortOutputsByActivation(array<uint> &inout arr)
{
	uint count = GetOutputCount();
	arr.resize(count);
	// Fill array with all output neuron positions
	for (uint i = 0; i < count; i++)
	{
		arr[i] = i + 1; // Neurons positions start with 1
	}
	// Now bubble sort by activation of the neurons if applicable
	if (count > 1)
	{
		double act1;
		double act2;
		uint pos1;
		uint pos2;
		bool more = false;
		
		do
		{
			more = false;
			for (uint i = 0; i < count - 1; i++)
			{
				pos1 = arr[i];
				pos2 = arr[i + 1];
				GetOutputAct(pos1, act1);
				GetOutputAct(pos2, act2);
				if (act1 > act2)
				{ // Swap positions in array in case order is incorrect
					arr[i] = pos2;
					arr[i + 1] = pos1;
					more = true;
				}
			}
			
		} while (more);
	}	
}


void main()
{
	OpenNet("Test.mbn");
	
	array<uint> outputs;
	SortOutputsByActivation(outputs);
	uint outCount = outputs.length();
	if (outCount > 1)
	{
		// Array elements are accessed 0-based. Last element is access via outputs[outCount - 1]
		uint outNum = outputs[outCount - 2]; // Second last element in sorted array
		SelectOutput(outNum, false); // Select the neuron output on screen (exclusively)
		string name;
		GetOutputName(outNum, name);
		Trace("Neuron with second highest activation is: " + name + " (neuron number " + outNum + ", see selection)\r\n");
		Trace("Neuron ascending activation order: ");
		for (uint i = 0; i < outCount; i++)
		{
			if (i < outCount - 1)
			{
				Trace(outputs[i] + ", ");
			}
			else
			{
				Trace(outputs[i] + "\r\n");
			}
		}
	}
}